# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class UserIdentities(object):

    def __init__(self, other=None, customerid=None, facebook=None, twitter=None, google=None, microsoft=None, yahoo=None, email=None, alias=None, facebook_custom_audience_id=None, other_id_2=None, other_id_3=None, other_id_4=None, other_id_5=None, other_id_6=None, other_id_7=None, other_id_8=None, other_id_9=None, other_id_10=None, mobile_number=None, phone_number_2=None, phone_number_3=None):
        """
        UserIdentities - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'other': 'str',
            'customerid': 'str',
            'facebook': 'str',
            'twitter': 'str',
            'google': 'str',
            'microsoft': 'str',
            'yahoo': 'str',
            'email': 'str',
            'alias': 'str',
            'facebook_custom_audience_id': 'str',
            'other_id_2': 'str',
            'other_id_3': 'str',
            'other_id_4': 'str',
            'other_id_5': 'str',
            'other_id_6': 'str',
            'other_id_7': 'str',
            'other_id_8': 'str',
            'other_id_9': 'str',
            'other_id_10': 'str',
            'mobile_number': 'str',
            'phone_number_2': 'str',
            'phone_number_3': 'str'
        }

        self.attribute_map = {
            'other': 'other',
            'customerid': 'customerid',
            'facebook': 'facebook',
            'twitter': 'twitter',
            'google': 'google',
            'microsoft': 'microsoft',
            'yahoo': 'yahoo',
            'email': 'email',
            'alias': 'alias',
            'facebook_custom_audience_id': 'facebook_custom_audience_id',
            'other_id_2': 'other_id_2',
            'other_id_3': 'other_id_3',
            'other_id_4': 'other_id_4',           
            'other_id_5': 'other_id_5',
            'other_id_6': 'other_id_6',
            'other_id_7': 'other_id_7',        
            'other_id_8': 'other_id_8',
            'other_id_9': 'other_id_9',
            'other_id_10': 'other_id_10',           
            'mobile_number': 'mobile_number',
            'phone_number_2': 'phone_number_2',
            'phone_number_3': 'phone_number_3'
        }

        self._other = other
        self._customerid = customerid
        self._facebook = facebook
        self._twitter = twitter
        self._google = google
        self._microsoft = microsoft
        self._yahoo = yahoo
        self._email = email
        self._alias = alias
        self._facebook_custom_audience_id = facebook_custom_audience_id
        self._other_id_2 = other_id_2
        self._other_id_3 = other_id_3
        self._other_id_4 = other_id_4
        self._other_id_5 = other_id_5
        self._other_id_6 = other_id_6
        self._other_id_7 = other_id_7
        self._other_id_8 = other_id_8
        self._other_id_9 = other_id_9
        self._other_id_10 = other_id_10
        self._mobile_number = mobile_number
        self._phone_number_2 = phone_number_2
        self._phone_number_3 = phone_number_3

    @property
    def other(self):
        """
        Gets the other of this UserIdentities.


        :return: The other of this UserIdentities.
        :rtype: str
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this UserIdentities.


        :param other: The other of this UserIdentities.
        :type: str
        """

        self._other = other

    @property
    def customerid(self):
        """
        Gets the customerid of this UserIdentities.


        :return: The customerid of this UserIdentities.
        :rtype: str
        """
        return self._customerid

    @customerid.setter
    def customerid(self, customerid):
        """
        Sets the customerid of this UserIdentities.


        :param customerid: The customerid of this UserIdentities.
        :type: str
        """

        self._customerid = customerid

    @property
    def facebook(self):
        """
        Gets the facebook of this UserIdentities.


        :return: The facebook of this UserIdentities.
        :rtype: str
        """
        return self._facebook

    @facebook.setter
    def facebook(self, facebook):
        """
        Sets the facebook of this UserIdentities.


        :param facebook: The facebook of this UserIdentities.
        :type: str
        """

        self._facebook = facebook

    @property
    def twitter(self):
        """
        Gets the twitter of this UserIdentities.


        :return: The twitter of this UserIdentities.
        :rtype: str
        """
        return self._twitter

    @twitter.setter
    def twitter(self, twitter):
        """
        Sets the twitter of this UserIdentities.


        :param twitter: The twitter of this UserIdentities.
        :type: str
        """

        self._twitter = twitter

    @property
    def google(self):
        """
        Gets the google of this UserIdentities.


        :return: The google of this UserIdentities.
        :rtype: str
        """
        return self._google

    @google.setter
    def google(self, google):
        """
        Sets the google of this UserIdentities.


        :param google: The google of this UserIdentities.
        :type: str
        """

        self._google = google

    @property
    def microsoft(self):
        """
        Gets the microsoft of this UserIdentities.


        :return: The microsoft of this UserIdentities.
        :rtype: str
        """
        return self._microsoft

    @microsoft.setter
    def microsoft(self, microsoft):
        """
        Sets the microsoft of this UserIdentities.


        :param microsoft: The microsoft of this UserIdentities.
        :type: str
        """

        self._microsoft = microsoft

    @property
    def yahoo(self):
        """
        Gets the yahoo of this UserIdentities.


        :return: The yahoo of this UserIdentities.
        :rtype: str
        """
        return self._yahoo

    @yahoo.setter
    def yahoo(self, yahoo):
        """
        Sets the yahoo of this UserIdentities.


        :param yahoo: The yahoo of this UserIdentities.
        :type: str
        """

        self._yahoo = yahoo

    @property
    def email(self):
        """
        Gets the email of this UserIdentities.


        :return: The email of this UserIdentities.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this UserIdentities.


        :param email: The email of this UserIdentities.
        :type: str
        """

        self._email = email

    @property
    def alias(self):
        """
        Gets the alias of this UserIdentities.


        :return: The alias of this UserIdentities.
        :rtype: str
        """
        return self._alias

    @alias.setter
    def alias(self, alias):
        """
        Sets the alias of this UserIdentities.


        :param alias: The alias of this UserIdentities.
        :type: str
        """

        self._alias = alias

    @property
    def facebook_custom_audience_id(self):
        """
        Gets the facebook_custom_audience_id of this UserIdentities.


        :return: The facebook_custom_audience_id of this UserIdentities.
        :rtype: str
        """
        return self._facebook_custom_audience_id

    @facebook_custom_audience_id.setter
    def facebook_custom_audience_id(self, facebook_custom_audience_id):
        """
        Sets the facebook_custom_audience_id of this UserIdentities.


        :param facebook_custom_audience_id: The facebook_custom_audience_id of this UserIdentities.
        :type: str
        """

        self._facebook_custom_audience_id = facebook_custom_audience_id

    @property
    def other_id_2(self):
        return self._other_id_2

    @other_id_2.setter
    def other_id_2(self, other_id_2):
        self._other_id_2 = other_id_2


    @property
    def other_id_3(self):
        return self._other_id_3

    @other_id_3.setter
    def other_id_3(self, other_id_3):
        self._other_id_3 = other_id_3


    @property
    def other_id_4(self):
        return self._other_id_4

    @other_id_4.setter
    def other_id_4(self, other_id_4):
        self._other_id_4 = other_id_4


    @property
    def other_id_5(self):
        return self._other_id_5

    @other_id_5.setter
    def other_id_5(self, other_id_5):
        self._other_id_5 = other_id_5


    @property
    def other_id_6(self):
        return self._other_id_6

    @other_id_6.setter
    def other_id_6(self, other_id_6):
        self._other_id_6 = other_id_6


    @property
    def other_id_7(self):
        return self._other_id_7

    @other_id_7.setter
    def other_id_7(self, other_id_7):
        self._other_id_7 = other_id_7


    @property
    def other_id_8(self):
        return self._other_id_8

    @other_id_8.setter
    def other_id_8(self, other_id_8):
        self._other_id_8 = other_id_8


    @property
    def other_id_9(self):
        return self._other_id_9

    @other_id_9.setter
    def other_id_9(self, other_id_9):
        self._other_id_9 = other_id_9


    @property
    def other_id_10(self):
        return self._other_id_10

    @other_id_10.setter
    def other_id_10(self, other_id_10):
        self._other_id_10 = other_id_10


    @property
    def mobile_number(self):
        return self._mobile_number

    @mobile_number.setter
    def mobile_number(self, mobile_number):
        self._mobile_number = mobile_number


    @property
    def phone_number_2(self):
        return self._phone_number_2

    @phone_number_2.setter
    def phone_number_2(self, phone_number_2):
        self._phone_number_2 = phone_number_2


    @property
    def phone_number_3(self):
        return self._phone_number_3

    @phone_number_3.setter
    def phone_number_3(self, phone_number_3):
        self._phone_number_3 = phone_number_3


    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

import sys
from setuptools import setup, find_packages

NAME = "mparticle"
VERSION = "0.12.1"


# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description='Python client for the mParticle platform',
    long_description='`Package Documentation <https://github.com/mParticle/mparticle-python-sdk/wiki>`_ \n\nThis SDK is a helper library for the mParticle server-to-server HTTP API, it exposes mParticle\'s schema as simple models and provides an HTTP client interface. This SDK is stateless and will only send the data that you populate, whereas our mobile SDKs will automatically collect app and device information, session events, install events, and maintain persistence.',
    author='Sam Dozor',
    author_email="support@mparticle.com",
    url="https://github.com/mParticle/mparticle-python-sdk",
    keywords=["mparticle analytics marketing"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    license='Apache 2.0',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re
import mparticle


class CommerceEvent(object):

    def __init__(self, product_action=None, timestamp_unixtime_ms=None,
                 event_id=None, source_message_id=None,
                 session_id=None, session_uuid=None,
                 custom_attributes=None, location=None,
                 device_current_state=None, promotion_action=None,
                 product_impressions=None, shopping_cart=None,
                 currency_code=None, screen_name=None,
                 is_non_interactive=None, custom_flags=None):
        """
        CommerceEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'timestamp_unixtime_ms': 'int',
            'event_id': 'int',
            'source_message_id': 'str',
            'session_id': 'int',
            'session_uuid': 'str',
            'custom_attributes': 'dict(str, str)',
            'location': 'GeoLocation',
            'device_current_state': 'DeviceCurrentState',
            'product_action': 'ProductAction',
            'promotion_action': 'PromotionAction',
            'product_impressions': 'list[ProductImpression]',
            'shopping_cart': 'ShoppingCart',
            'currency_code': 'str',
            'screen_name': 'str',
            'is_non_interactive': 'bool',
            'custom_flags': 'dict(str, str)',
        }

        self.attribute_map = {
            'timestamp_unixtime_ms': 'timestamp_unixtime_ms',
            'event_id': 'event_id',
            'source_message_id': 'source_message_id',
            'session_id': 'session_id',
            'session_uuid': 'session_uuid',
            'custom_attributes': 'custom_attributes',
            'location': 'location',
            'device_current_state': 'device_current_state',
            'product_action': 'product_action',
            'promotion_action': 'promotion_action',
            'product_impressions': 'product_impressions',
            'shopping_cart': 'shopping_cart',
            'currency_code': 'currency_code',
            'screen_name': 'screen_name',
            'is_non_interactive': 'is_non_interactive',
            'custom_flags': 'custom_flags',
        }

        self._timestamp_unixtime_ms = timestamp_unixtime_ms
        self._event_id = event_id
        self._source_message_id = source_message_id
        self._session_id = session_id
        self._session_uuid = session_uuid
        self.custom_attributes = custom_attributes
        self._location = location
        self._device_current_state = device_current_state
        self._product_action = product_action
        self._promotion_action = promotion_action
        self._product_impressions = product_impressions
        self._shopping_cart = shopping_cart
        self._currency_code = currency_code
        self._screen_name = screen_name
        self._is_non_interactive = is_non_interactive
        self._custom_flags = custom_flags

        if (product_action is None and
            product_impressions is None and
                promotion_action is None):
            raise ValueError(
                "At least one of: product_action, product_impressions, or promotion_action is required."
            )

    @property
    def timestamp_unixtime_ms(self):
        """
        Gets the timestamp_unixtime_ms of this CommerceEvent.


        :return: The timestamp_unixtime_ms of this CommerceEvent.
        :rtype: int
        """
        return self._timestamp_unixtime_ms

    @timestamp_unixtime_ms.setter
    def timestamp_unixtime_ms(self, timestamp_unixtime_ms):
        """
        Sets the timestamp_unixtime_ms of this CommerceEvent.


        :param timestamp_unixtime_ms: The timestamp_unixtime_ms of this CommerceEvent.
        :type: int
        """

        self._timestamp_unixtime_ms = timestamp_unixtime_ms

    @property
    def event_id(self):
        """
        Gets the event_id of this CommerceEvent.


        :return: The event_id of this CommerceEvent.
        :rtype: int
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """
        Sets the event_id of this CommerceEvent.


        :param event_id: The event_id of this CommerceEvent.
        :type: int
        """

        self._event_id = event_id

    @property
    def source_message_id(self):
        """
        Gets the source_message_id of this CommerceEvent.


        :return: The source_message_id of this CommerceEvent.
        :rtype: str
        """
        return self._source_message_id

    @source_message_id.setter
    def source_message_id(self, source_message_id):
        """
        Sets the source_message_id of this CommerceEvent.


        :param source_message_id: The source_message_id of this CommerceEvent.
        :type: str
        """

        self._source_message_id = source_message_id

    @property
    def session_id(self):
        """
        Gets the session_id of this CommerceEvent.


        :return: The session_id of this CommerceEvent.
        :rtype: int
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """
        Sets the session_id of this CommerceEvent.


        :param session_id: The session_id of this CommerceEvent.
        :type: int
        """

        self._session_id = session_id

    @property
    def session_uuid(self):
        """
        Gets the session_uuid of this CommerceEvent.


        :return: The session_uuid of this CommerceEvent.
        :rtype: str
        """
        return self._session_uuid

    @session_uuid.setter
    def session_uuid(self, session_uuid):
        """
        Sets the session_uuid of this CommerceEvent.


        :param session_uuid: The session_uuid of this CommerceEvent.
        :type: str
        """

        self._session_uuid = session_uuid

    @property
    def custom_attributes(self):
        """
        Gets the custom_attributes of this CommerceEvent.


        :return: The custom_attributes of this CommerceEvent.
        :rtype: dict(str, str)
        """

        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        """
        Sets the custom_attributes of this CommerceEvent.


        :param custom_attributes: The custom_attributes of this CommerceEvent.
        :type: dict(str, str)
        """

        if not mparticle.ApiClient.validate_attribute_bag_values(custom_attributes):
            raise ValueError(
                "Invalid custom_attributes passed to CommerceEvent: " + str(custom_attributes))

        self._custom_attributes = custom_attributes

    @property
    def location(self):
        """
        Gets the location of this CommerceEvent.


        :return: The location of this CommerceEvent.
        :rtype: GeoLocation
        """
        return self._location

    @location.setter
    def location(self, location):
        """
        Sets the location of this CommerceEvent.


        :param location: The location of this CommerceEvent.
        :type: GeoLocation
        """

        self._location = location

    @property
    def device_current_state(self):
        """
        Gets the device_current_state of this CommerceEvent.


        :return: The device_current_state of this CommerceEvent.
        :rtype: DeviceCurrentState
        """
        return self._device_current_state

    @device_current_state.setter
    def device_current_state(self, device_current_state):
        """
        Sets the device_current_state of this CommerceEvent.


        :param device_current_state: The device_current_state of this CommerceEvent.
        :type: DeviceCurrentState
        """

        self._device_current_state = device_current_state

    @property
    def product_action(self):
        """
        Gets the product_action of this CommerceEvent.


        :return: The product_action of this CommerceEvent.
        :rtype: ProductAction
        """
        return self._product_action

    @product_action.setter
    def product_action(self, product_action):
        """
        Sets the product_action of this CommerceEvent.


        :param product_action: The product_action of this CommerceEvent.
        :type: ProductAction
        """

        self._product_action = product_action

    @property
    def promotion_action(self):
        """
        Gets the promotion_action of this CommerceEvent.


        :return: The promotion_action of this CommerceEvent.
        :rtype: PromotionAction
        """
        return self._promotion_action

    @promotion_action.setter
    def promotion_action(self, promotion_action):
        """
        Sets the promotion_action of this CommerceEvent.


        :param promotion_action: The promotion_action of this CommerceEvent.
        :type: PromotionAction
        """

        self._promotion_action = promotion_action

    @property
    def product_impressions(self):
        """
        Gets the product_impressions of this CommerceEvent.


        :return: The product_impressions of this CommerceEvent.
        :rtype: list[ProductImpression]
        """
        return self._product_impressions

    @product_impressions.setter
    def product_impressions(self, product_impressions):
        """
        Sets the product_impressions of this CommerceEvent.


        :param product_impressions: The product_impressions of this CommerceEvent.
        :type: list[ProductImpression]
        """

        self._product_impressions = product_impressions

    @property
    def shopping_cart(self):
        """
        Gets the shopping_cart of this CommerceEvent.


        :return: The shopping_cart of this CommerceEvent.
        :rtype: ShoppingCart
        """
        return self._shopping_cart

    @shopping_cart.setter
    def shopping_cart(self, shopping_cart):
        """
        Sets the shopping_cart of this CommerceEvent.


        :param shopping_cart: The shopping_cart of this CommerceEvent.
        :type: ShoppingCart
        """

        self._shopping_cart = shopping_cart

    @property
    def currency_code(self):
        """
        Gets the currency_code of this CommerceEvent.


        :return: The currency_code of this CommerceEvent.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this CommerceEvent.


        :param currency_code: The currency_code of this CommerceEvent.
        :type: str
        """

        self._currency_code = currency_code

    @property
    def screen_name(self):
        """
        Gets the screen_name of this CommerceEvent.


        :return: The screen_name of this CommerceEvent.
        :rtype: str
        """
        return self._screen_name

    @screen_name.setter
    def screen_name(self, screen_name):
        """
        Sets the screen_name of this CommerceEvent.


        :param screen_name: The screen_name of this CommerceEvent.
        :type: str
        """

        self._screen_name = screen_name

    @property
    def is_non_interactive(self):
        """
        Gets the is_non_interactive of this CommerceEvent.


        :return: The is_non_interactive of this CommerceEvent.
        :rtype: bool
        """
        return self._is_non_interactive

    @is_non_interactive.setter
    def is_non_interactive(self, is_non_interactive):
        """
        Sets the is_non_interactive of this CommerceEvent.


        :param is_non_interactive: The is_non_interactive of this CommerceEvent.
        :type: bool
        """

        self._is_non_interactive = is_non_interactive

    @property
    def custom_flags(self):
        """
        Gets the custom_flags of this CommerceEvent.


        :return: The custom_flags of this CommerceEvent.
        :rtype: dict(str, str)
        """
        return self._custom_flags

    @custom_flags.setter
    def custom_flags(self, custom_flags):
        """
        Sets the custom_flags of this CommerceEvent.


        :param custom_flags: The custom_flags of this CommerceEvent.
        :type: dict(str, str)
        """

        self._custom_flags = custom_flags

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re
from .api_response import ApiResponse
from .api_response_errors import ApiResponseErrors
from .app_event import AppEvent
from .application_information import ApplicationInformation
from .application_state_transition_event import ApplicationStateTransitionEvent
from .attribution_info import AttributionInfo
from .breadcrumb_event import BreadcrumbEvent
from .consent_state import ConsentState
from .commerce_event import CommerceEvent
from .crash_report_event import CrashReportEvent
from .device_current_state import DeviceCurrentState
from .device_information import DeviceInformation
from .event_base import EventBase
from .event_data import EventData
from .first_run_event import FirstRunEvent
from .geo_location import GeoLocation
from .media_info import MediaInfo
from .network_performance_event import NetworkPerformanceEvent
from .opt_out_event import OptOutEvent
from .product import Product
from .product_action import ProductAction
from .product_impression import ProductImpression
from .profile_event import ProfileEvent
from .promotion import Promotion
from .promotion_action import PromotionAction
from .push_message_event import PushMessageEvent
from .push_registration_event import PushRegistrationEvent
from .screen_view_event import ScreenViewEvent
from .session_end_event import SessionEndEvent
from .session_start_event import SessionStartEvent
from .shopping_cart import ShoppingCart
from .source_information import SourceInformation
from .user_identities import UserIdentities


class Batch(object):

    def __init__(self, events=None, source_request_id=None, environment=None, ip=None, schema_version=None, device_info=None, application_info=None, user_attributes=None, deleted_user_attributes=None, user_identities=None, api_key=None, mpid=None, mp_deviceid=None, consent_state=None, context=None):
        """
        Batch - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'events': 'list[EventBase]',
            'source_request_id': 'str',
            'environment': 'str',
            'ip': 'str',
            'schema_version': 'int',
            'device_info': 'DeviceInformation',
            'application_info': 'ApplicationInformation',
            'user_attributes': 'object',
            'deleted_user_attributes': 'list[str]',
            'user_identities': 'UserIdentities',
            'consent_state': 'ConsentState',
            'api_key': 'str',
            'mpid': 'int',
            'mp_deviceid': 'str',
            'context': 'BatchContext'
        }

        self.attribute_map = {
            'events': 'events',
            'source_request_id': 'source_request_id',
            'environment': 'environment',
            'ip': 'ip',
            'schema_version': 'schema_version',
            'device_info': 'device_info',
            'application_info': 'application_info',
            'user_attributes': 'user_attributes',
            'deleted_user_attributes': 'deleted_user_attributes',
            'user_identities': 'user_identities',
            'consent_state': 'consent_state',
            'api_key': 'api_key',
            'mpid': 'mpid',
            'mp_deviceid': 'mp_deviceid',
            'context': 'context',
        }

        self._api_key = api_key
        self._events = events
        self._source_request_id = source_request_id
        self._environment = environment
        self._ip = ip
        self._schema_version = schema_version
        self._device_info = device_info
        self._application_info = application_info
        self._user_attributes = user_attributes
        self._consent_state = consent_state
        self._deleted_user_attributes = deleted_user_attributes
        self._user_identities = user_identities
        self._mpid = mpid
        self._mp_deviceid = mp_deviceid
        self._allowed_types = {type(AppEvent('empty')): 'custom_event',
                               type(FirstRunEvent()): 'first_run',
                               type(SessionStartEvent()): 'session_start',
                               type(SessionEndEvent()): 'session_end',
                               type(ApplicationStateTransitionEvent()): 'application_state_transition',
                               type(ScreenViewEvent()): 'screen_view',
                               type(PushRegistrationEvent()): 'push_registration',
                               type(ProfileEvent()): 'profile',
                               type(OptOutEvent()): 'opt_out',
                               type(BreadcrumbEvent()): 'breadcrumb',
                               type(CommerceEvent(ProductAction('purchase'))): 'commerce_event',
                               type(PushMessageEvent()): 'push_message',
                               type(NetworkPerformanceEvent()): 'network_performance',
                               type(CrashReportEvent()): 'commerce_event'}
        self._context = context

    @property
    def events(self):
        """
        Gets the events of this Batch.


        :return: The events of this Batch.
        :rtype: list[EventBase]
        """
        return self._events

    @events.setter
    def events(self, events):
        """
        Sets the events of this Batch.


        :param events: The events of this Batch.
        :type: list[EventBase]
        """
        self._events = [self.__convert_to_eventbase(event) for event in events]

    def __convert_to_eventbase(self, event):
        event_type = type(event)
        if (event_type is EventBase):
            return event

        if event_type not in self._allowed_types:
            raise ValueError(
                "Invalid event type: " +
                str(event_type) + " added to batch, must be one of {0}"
                .format(self._allowed_types.keys())
            )

        event_base = EventBase()
        event_base.event_type = self._allowed_types[event_type]
        event_base.data = event
        return event_base

    @property
    def source_request_id(self):
        """
        Gets the source_request_id of this Batch.


        :return: The source_request_id of this Batch.
        :rtype: str
        """
        return self._source_request_id

    @source_request_id.setter
    def source_request_id(self, source_request_id):
        """
        Sets the source_request_id of this Batch.


        :param source_request_id: The source_request_id of this Batch.
        :type: str
        """

        self._source_request_id = source_request_id

    @property
    def environment(self):
        """
        Gets the environment of this Batch.


        :return: The environment of this Batch.
        :rtype: str
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """
        Sets the environment of this Batch.


        :param environment: The environment of this Batch.
        :type: str
        """
        allowed_values = ["production", "development"]
        if environment not in allowed_values:
            raise ValueError(
                "Invalid value for `environment` ({0}), must be one of {1}"
                .format(environment, allowed_values)
            )

        self._environment = environment

    @property
    def api_key(self):
        """
        Gets the api_key of this Batch. This should only be used while uploading
        data via Amazon SQS.


        :return: The api_key of this Batch.
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """
        Sets the api_key of this Batch. This should only be used while uploading
        data via Amazon SQS.


        :param ip: The api_key of this Batch.
        :type: str
        """

        self._api_key = api_key

    @property
    def ip(self):
        """
        Gets the ip address of this Batch.


        :return: The ip of this Batch.
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """
        Sets the ip address of this Batch.


        :param ip: The ip of this Batch.
        :type: str
        """

        self._ip = ip

    @property
    def schema_version(self):
        """
        Gets the schema_version of this Batch.


        :return: The schema_version of this Batch.
        :rtype: int
        """
        return self._schema_version

    @schema_version.setter
    def schema_version(self, schema_version):
        """
        Sets the schema_version of this Batch.


        :param schema_version: The schema_version of this Batch.
        :type: int
        """

        self._schema_version = schema_version

    @property
    def device_info(self):
        """
        Gets the device_info of this Batch.


        :return: The device_info of this Batch.
        :rtype: DeviceInformation
        """
        return self._device_info

    @device_info.setter
    def device_info(self, device_info):
        """
        Sets the device_info of this Batch.


        :param device_info: The device_info of this Batch.
        :type: DeviceInformation
        """

        self._device_info = device_info

    @property
    def application_info(self):
        """
        Gets the application_info of this Batch.


        :return: The application_info of this Batch.
        :rtype: ApplicationInformation
        """
        return self._application_info

    @application_info.setter
    def application_info(self, application_info):
        """
        Sets the application_info of this Batch.


        :param application_info: The application_info of this Batch.
        :type: ApplicationInformation
        """

        self._application_info = application_info

    @property
    def user_attributes(self):
        """
        Gets the user_attributes of this Batch.


        :return: The user_attributes of this Batch.
        :rtype: object
        """
        return self._user_attributes

    @user_attributes.setter
    def user_attributes(self, user_attributes):
        """
        Sets the user_attributes of this Batch.

        User attributes must be a dictionary with strings for keys and either strings or arrays of strings as values,
        for example: batch.user_attributes = {"eyes":"brown","favorite_foods":["indian","chinese","italian"]}
        :param user_attributes: The user_attributes of this Batch.
        :type: object
        """

        self._user_attributes = user_attributes

    @property
    def deleted_user_attributes(self):
        """
        Gets the deleted_user_attributes of this Batch.


        :return: The deleted_user_attributes of this Batch.
        :rtype: list[str]
        """
        return self._deleted_user_attributes

    @deleted_user_attributes.setter
    def deleted_user_attributes(self, deleted_user_attributes):
        """
        Sets the deleted_user_attributes of this Batch.


        :param deleted_user_attributes: The deleted_user_attributes of this Batch.
        :type: list[str]
        """

        self._deleted_user_attributes = deleted_user_attributes

    @property
    def user_identities(self):
        """
        Gets the user_identities of this Batch.


        :return: The user_identities of this Batch.
        :rtype: UserIdentities
        """
        return self._user_identities

    @user_identities.setter
    def user_identities(self, user_identities):
        """
        Sets the user_identities of this Batch.


        :param user_identities: The user_identities of this Batch.
        :type: UserIdentities
        """

        self._user_identities = user_identities

    @property
    def mpid(self):
        """
            Gets the mpid of this Batch.


            :return: The mpid of this Batch.
            :rtype: str
            """
        return self._mpid

    @mpid.setter
    def mpid(self, mpid):
        """
            Sets the mpid of this Batch.


            :param mpid: The mpid of this Batch.
            :type: str
            """

        self._mpid = mpid

    @property
    def mp_deviceid(self):
        """
            Gets the mp_deviceid of this Batch.


            :return: The mp_deviceid of this Batch.
            :rtype: str
            """
        return self._mp_deviceid

    @mp_deviceid.setter
    def mp_deviceid(self, mp_deviceid):
        """
            Sets the mp_deviceid of this Batch.


            :param mp_deviceid: The mp_deviceid of this Batch.
            :type: str
            """

        self._mp_deviceid = mp_deviceid

    @property
    def consent_state(self):
        """
        Gets the ConsentState of this Batch

        :return: The consent_state of this Batch
        :rtype: dict
        """

        return self._consent_state

    @consent_state.setter
    def consent_state(self, consent_state):
        """
        Sets the consent_state of this Batch.


        :param consent_state: The consent_state of this Batch.
        :type: str
        """

        self._consent_state = consent_state

    @property
    def context(self):
        """
        Gets the BatchContext of this Batch

        :return: The context of this Batch
        :rtype: BatchContext
        """

        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the BatchContext of this Batch.


        :param context: The context of this Batch.
        :type: BatchContext
        """

        self._context = context

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    mParticle

    mParticle Event API

    OpenAPI spec version: 1.0.1
    Contact: support@mparticle.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class ApplicationInformation(object):

    def __init__(self, application_name=None, application_version=None, install_referrer=None, package=None):
        """
        ApplicationInformation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'application_name': 'str',
            'application_version': 'str',
            'install_referrer': 'str',
            'package': 'str'
        }

        self.attribute_map = {
            'application_name': 'application_name',
            'application_version': 'application_version',
            'install_referrer': 'install_referrer',
            'package': 'package'
        }

        self._application_name = application_name
        self._application_version = application_version
        self._install_referrer = install_referrer
        self._package = package

    @property
    def application_name(self):
        """
        Gets the application_name of this ApplicationInformation.


        :return: The application_name of this ApplicationInformation.
        :rtype: str
        """
        return self._application_name

    @application_name.setter
    def application_name(self, application_name):
        """
        Sets the application_name of this ApplicationInformation.


        :param application_name: The application_name of this ApplicationInformation.
        :type: str
        """

        self._application_name = application_name

    @property
    def application_version(self):
        """
        Gets the application_version of this ApplicationInformation.


        :return: The application_version of this ApplicationInformation.
        :rtype: str
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """
        Sets the application_version of this ApplicationInformation.


        :param application_version: The application_version of this ApplicationInformation.
        :type: str
        """

        self._application_version = application_version

    @property
    def install_referrer(self):
        """
        Gets the install_referrer of this ApplicationInformation.


        :return: The install_referrer of this ApplicationInformation.
        :rtype: str
        """
        return self._install_referrer

    @install_referrer.setter
    def install_referrer(self, install_referrer):
        """
        Sets the install_referrer of this ApplicationInformation.


        :param install_referrer: The install_referrer of this ApplicationInformation.
        :type: str
        """

        self._install_referrer = install_referrer

    @property
    def package(self):
        """
        Gets the package of this ApplicationInformation.


        :return: The package of this ApplicationInformation.
        :rtype: str
        """
        return self._package

    @package.setter
    def package(self, package):
        """
        Sets the package of this ApplicationInformation.


        :param package: The package of this ApplicationInformation.
        :type: str
        """

        self._package = package

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
